@@ -496,6 +496,8 @@ table.docutils th {
                     fh.write(_write(".. glossary::\n\n"))
                     columns = {k: v["items"] for k, v in schema.columns_specs.items()}
                     for colname, colspecs in columns.items():
+                        bookmark = f".. _field_{tab}-{colname}:\n"
+                        fh.write(bookmark)
                         col_status = field_status(colname, schema)
                         # add label
                         if col_status == "padded":
